@@ -14,12 +14,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __GNOME_CMD_STATE_H__
 #define __GNOME_CMD_STATE_H__
 
+G_BEGIN_DECLS
+
 typedef struct {
     GnomeVFSURI *active_dir_uri;
     GnomeVFSURI *inactive_dir_uri;
@@ -29,4 +31,6 @@ typedef struct {
     GList *inactive_dir_selected_files;
 } GnomeCmdState;
 
+G_END_DECLS
+
 #endif //__GNOME_CMD_STATE_H__
