@@ -1,6 +1,6 @@
 /*
-  GNOME Commander - A GNOME based file manager 
-  Copyright (C) 2001-2004 Marcus Bjurman
+  GNOME Commander - A GNOME based file manager
+  Copyright (C) 2001-2006 Marcus Bjurman
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -14,8 +14,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #ifndef __GNOME_CMD_ADVRENAME_LEXER_H__
 #define __GNOME_CMD_ADVRENAME_LEXER_H__
@@ -28,4 +28,6 @@ void gnome_cmd_advrename_parse_fname(const char *fname);
 char *gnome_cmd_advrename_gen_fname(char *new_fname, size_t new_fname_size, GnomeCmdFile *finfo);
 
 
-#endif //__GNOME_CMD_ADVRENAME_LEXER_H__
+G_END_DECLS
+
+#endif // __GNOME_CMD_ADVRENAME_LEXER_H__
