@@ -1,6 +1,6 @@
 /*
-    GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2004 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,20 +14,22 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
 #ifndef __GNOME_CMD_CHMOD_COMPONENT_H__
 #define __GNOME_CMD_CHMOD_COMPONENT_H__
 
 #include "gnome-cmd-file.h"
 
+G_BEGIN_DECLS
 
 #define GNOME_CMD_CHMOD_COMPONENT(obj) \
-	GTK_CHECK_CAST (obj, gnome_cmd_chmod_component_get_type (), GnomeCmdChmodComponent)
+    GTK_CHECK_CAST (obj, gnome_cmd_chmod_component_get_type (), GnomeCmdChmodComponent)
 #define GNOME_CMD_CHMOD_COMPONENT_CLASS(klass) \
-	GTK_CHECK_CLASS_CAST (klass, gnome_cmd_chmod_component_get_type (), GnomeCmdChmodComponentClass)
+    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_chmod_component_get_type (), GnomeCmdChmodComponentClass)
 #define GNOME_CMD_IS_CHMOD_COMPONENT(obj) \
-	GTK_CHECK_TYPE (obj, gnome_cmd_chmod_component_get_type ())
+    GTK_CHECK_TYPE (obj, gnome_cmd_chmod_component_get_type ())
 
 
 typedef struct _GnomeCmdChmodComponent GnomeCmdChmodComponent;
@@ -38,16 +40,16 @@ typedef struct _GnomeCmdChmodComponentClass GnomeCmdChmodComponentClass;
 
 struct _GnomeCmdChmodComponent
 {
-	GtkVBox parent;
-	GnomeCmdChmodComponentPrivate *priv;
+    GtkVBox parent;
+    GnomeCmdChmodComponentPrivate *priv;
 };
 
 
 struct _GnomeCmdChmodComponentClass
 {
-	GtkVBoxClass parent_class;
+    GtkVBoxClass parent_class;
 
-	void (* perms_changed)      (GnomeCmdChmodComponent *component);
+    void (* perms_changed)      (GnomeCmdChmodComponent *component);
 };
 
 
@@ -57,17 +59,13 @@ gnome_cmd_chmod_component_new (GnomeVFSFilePermissions perms);
 GtkType
 gnome_cmd_chmod_component_get_type (void);
 
-GnomeVFSFilePermissions 
+GnomeVFSFilePermissions
 gnome_cmd_chmod_component_get_perms (GnomeCmdChmodComponent *component);
 
 void
 gnome_cmd_chmod_component_set_perms (GnomeCmdChmodComponent *component,
-									 GnomeVFSFilePermissions perms);
-
-
-
-
-
-#endif //__GNOME_CMD_CHMOD_COMPONENT_H__
+                                     GnomeVFSFilePermissions perms);
 
+G_END_DECLS
 
+#endif // __GNOME_CMD_CHMOD_COMPONENT_H__
